useMart), they will return a character vector of
annotation sources that exist for that particular Biomart and species. If
called with a 'mart' connection and a character vector of annotation
sources, they will return a list that is intended to be used by other
functions for creating HTML pages. This last function doesn't have any real
utility for the end user.
annBM(mart, annot, species)useMart.linksBM is intended to list those annotation sources that may be
turned into hyperlinks whereas annBM is intended to list those
annotation sources that will not be linked.
These functions have only a few of the possible annotation sources, and currently there is no simple way to extend these sources. Additions to the list are possible, however. Please contact me if there is something in particular that should be included in either list.