ExpressionSet and some
comparisons and output HTML tables. It is very similar to foldFilt
except it uses the biomaRt package to annotate genes and the annotate
package to create the HTML table(s).
foldFiltBM(object, fold = 1, groups, comps, compnames, species, links = linksBM()[1:3], otherann = annBM()[1:3], filterfun = NULL, ann.source = "entrezgene", affyid = FALSE, html = TRUE, text = TRUE, save = FALSE)ExpressionSet objectlinksBM for possible values.annBM for possible values.genefilter to filter the data using additional
criteria. See details for more informationTRUETRUETRUE, a list will be returned. The first item
in the list will be a vector showing the number of 'significant' genes for
each comparison. The second item will be a matrix of -1's, 0's and 1's
indicating a significant difference, and the direction of the difference.
The first item is useful for creating Sweave - based reports and the second
is useful for making Vennn diagrams using vennDiagram from the limma
package.This function currently only supports Affymetrix data. It is designed for Affymetrix chips that don't have an annotation package, which includes data that have been analyzed using the 're-mapped' CDFs supplied to BioC by MBNI at University of Michigan.
The IDs that will be used to annotate the genes depend on the source of the
data. If, for example, one is using an Affymetrix chip that doesn't have a
BioC annotation package, then the IDs will be Affymetrix IDs. To find out
the correct name to use for the ann.source argument, one can create a
connection to a Biomart database using useMart and
then get a list of available Affy arrays using getAffyArrays.
If one is using one of the re-mapped CDFs from MBNI at University of
Michigan, then the IDs to use depend on the mapping used to create the CDF.
At this time, only three types of CDFs can be used; EntrezGene, UniGene, and
RefSeq. One can determine the correct ann.source argument by creating a
connection to a Biomart database, and then calling linksBM(mart,
linksBM())[[3]].
One can also protect against selecting probesets that have very small expression values for all samples (which likely have a large fold change due to noise, rather than signal) by using the filterfun argument. An example would be:
f <- kOverA(1, 6)
filt <- filterfun(f)
Then add filterfun = filt as an argument to the call to foldFilt.