Learn R Programming

affycoretools (version 1.38.0)

houtSel: Internal functions for hyperGoutput

Description

These functions are internal functions for hyperGoutput and are not intended to be called directly by the end user.

Usage

houtSel(tab, eset, fit, comp, statistics, html, text)

Arguments

tab
A data.frame, resulting from a call to probeSetSummary
eset
An link[Biobase:class.ExpressionSet]{ExpressionSet} object
fit
An MArrayLM object, resulting from a call to eBayes
comp
Numeric vector of length one, designating which comparison to select from the MArrayLM object
statistics
Any or all of 'tstat', 'pval', 'FC', used to control the output of statistics from the MArrayLM object
html
Boolean. Output HTML tables? Defaults to TRUE
text
Boolean. Output text tables? Defaults to TRUE

Value

Nothing is returned. These functions are called solely for their side effect, the output of HTML and/or text tables.

Details

These functions control the output and ordering of the probesets for the hyperGoutput function.