Learn R Programming

affycoretools (version 1.38.0)

limma2annaffy: Function to Create HTML Tables from limma Objects

Description

This function is designed to take an ExpressionSet and an lmFit, model.matrix, and contrast object from limma and convert into HTML tables using annaffy. The alternate function limma2annaffy.na is designed to be run without user intervention.

Usage

limma2annaffy(eset, fit, design, contrast, lib, adjust = "fdr", anncols = aaf.handler()[c(1:3, 6:7, 9:12)], number = 30, pfilt = NULL, fldfilt = NULL, tstat = TRUE, pval = TRUE, FC = TRUE, expression = TRUE, html = TRUE, text = FALSE, save = FALSE, addname = NULL, addtitle = NULL, interactive = TRUE, natFC = FALSE)

Arguments

eset
An ExpressionSet containing affymetrix expression values.
fit
An lmFit object.
design
A model.matrix object.
contrast
A contrasts matrix from limma.
lib
An annotation package for the Affy chips used.
adjust
Multiplicity adjustment. Choices are "fdr","holm","hommel","bonferroni", or "none". Partial matching allowed.
anncols
A vector of things to annotate, produced by a call to aaf.handler().
number
Number of genes to output to table. See details for more information.
pfilt
A p-value to filter output. See details for more information.
fldfilt
A fold change to filter output. See details for more information.
tstat
Boolean: Output t-statistics in table? Defaults to FALSE.
pval
Boolean: Output (adjusted) p-values in table? Defaults to FALSE.
FC
Boolean: Output fold changes in table? Defaults to FALSE.
expression
Boolean: Output expression values in table? Defaults to TRUE.
html
Boolean: Output data in HTML tables? Defaults to TRUE.
text
Boolean: Output data in text tables? Defaults to TRUE.
save
Boolean: Save tables as R objects for further processing? Defaults to FALSE.
addname
A character vector to add to the end of the automatically generated output file names. Useful for multiple calls to eliminate over-writing of existing HTML or text tables.
addtitle
A character vector to add to the title for the HTML table. By default the title will be the same as the filename. If the addname argument is not NULL, then that will be appended to the filename (and will be used as the HTML title). If addtitle is not NULL, it will be appended to the filename and that will then be used as the HTML table title.
interactive
Boolean: Is this an interactive call, or run as part of a script (e.g., in an Sweave document)? Defaults to TRUE
natFC
Boolean: Add 'unlogged' fold change to output? This is intended for people who don't understand logs or fractions. If the fold change is positive, it is simply exponentiated (e.g., 2^x where x is the log fold change). If negative, we use -2^(-x), so e.g., a log fold change of -2 will result in a -4.

Value

If save is TRUE, a list of tables from topTable will be output.

Details

This function is designed to automatically output HTML or text tables, with filenames taken from the column names of the contrast matrix. The number of genes output can be controlled several different ways. First, if pfilt and fldfilt are both NULL, the top genes will be output based on the number variable. Otherwise, the genes are filtered based on p-value, fold change, or both. If the genes are filtered this way, the number of genes to be output will be listed and the filter(s) can then be adjusted if necessary.

This function currently only supports Affymetrix data.

See Also

topTable, aafTableAnn