ExpressionSet and an
lmFit, model.matrix, and contrast object from limma and
convert into HTML and text tables using biomaRt. The alternate function
limma2biomaRt.na is designed to be run without user intervention.
limma2biomaRt(eset, fit, design, contrast, species, links = linksBM()[1:3], otherdata = annBM()[1:3], ann.source = "entrezgene", adjust = "fdr", number = 30, pfilt = NULL, fldfilt = NULL, tstat = TRUE, pval = TRUE, FC = TRUE, expression = TRUE, html = TRUE, text = TRUE, save = FALSE, addname = NULL, interactive = TRUE, affyid = FALSE)ExpressionSet containing affymetrix expression values.lmFit object.model.matrix object.linksBM for possible values.annBM for possible values.FALSE.FALSE.FALSE.TRUE.TRUE.TRUEFALSE.Sweave document)? Defaults to TRUEsave is TRUE, a list of tables from
topTable will be output.
NULL, the top genes will be output based on the
number variable. Otherwise, the genes are filtered based on p-value,
fold change, or both. If the genes are filtered this way, the number of
genes to be output will be listed and the filter(s) can then be adjusted if
necessary.This function currently only supports Affymetrix data. It is designed for Affymetrix chips that don't have an annotation package, which includes data that have been analyzed using the 're-mapped' CDFs supplied to BioC by MBNI at University of Michigan.
The IDs that will be used to annotate the genes depend on the source of the
data. If, for example, one is using an Affymetrix chip that doesn't have a
BioC annotation package, then the IDs will be Affymetrix IDs. To find out
the correct name to use for the ann.source argument, one can create a
connection to a Biomart database using useMart and
then get a list of available Affy arrays using
listFilters.
If one is using one of the re-mapped CDFs from MBNI at University of
Michigan, then the IDs to use depend on the mapping used to create the CDF.
At this time, only three types of CDFs can be used; EntrezGene, UniGene, and
RefSeq. One can determine the correct ann.source argument by creating a
connection to a Biomart database, and then calling linksBM(mart,
linksBM())[[3]].
topTable,
aafTableAnn