probes2table, except it uses
the biomaRt package to annotate genes, and the annotate
package to create the HTML table.
probes2tableBM(eset, probids, species, filename, otherdata = NULL, links = linksBM()[1:3], otherann = annBM()[1:3], ann.source = "entrezgene", express = TRUE, html = TRUE, text = TRUE, affyid = FALSE)ExpressionSet containing Affy expression values.linksBM for possible values.annBM for possible values.TRUE.TRUETRUEThe IDs that will be used to annotate the genes depend on the source of the
data. If, for example, one is using an Affymetrix chip that doesn't have a
BioC annotation package, then the IDs will be Affymetrix IDs. To find out
the correct name to use for the ann.source argument, one can create a
connection to a Biomart database using useMart and
then get a list of available Affy arrays using
listFilters.
If one is using one of the re-mapped CDFs from MBNI at University of
Michigan, then the IDs to use depend on the mapping used to create the CDF.
At this time, only three types of CDFs can be used; EntrezGene, UniGene, and
RefSeq. One can determine the correct ann.source argument by creating a
connection to a Biomart database, and then calling linksBM(mart,
linksBM())[[3]].
topTable