ExpressionSet and an
lmFit, model.matrix, and contrast object from limma and
convert into HTML tables using annaffy. The alternate function
limma2annaffy.na is designed to be run without user intervention.
limma2annaffy(eset, fit, design, contrast, lib, adjust = "fdr", anncols = aaf.handler()[c(1:3, 6:7, 9:12)], number = 30, pfilt = NULL, fldfilt = NULL, tstat = TRUE, pval = TRUE, FC = TRUE, expression = TRUE, html = TRUE, text = FALSE, save = FALSE, addname = NULL, addtitle = NULL, interactive = TRUE, natFC = FALSE)ExpressionSet containing affymetrix expression values.lmFit object.model.matrix object.FALSE.FALSE.FALSE.TRUE.TRUE.TRUE.FALSE.NULL, then that will be appended to the filename (and
will be used as the HTML title). If addtitle is not NULL, it will be
appended to the filename and that will then be used as the HTML table title.Sweave document)? Defaults to TRUEsave is TRUE, a list of tables from
topTable will be output.
NULL, the top genes will be output based on the
number variable. Otherwise, the genes are filtered based on p-value,
fold change, or both. If the genes are filtered this way, the number of
genes to be output will be listed and the filter(s) can then be adjusted if
necessary.This function currently only supports Affymetrix data.
topTable,
aafTableAnn